@@ -23,13 +23,13 @@ from neutron.db.models import address_scope as address_scope_db
 from neutron.db.models import l3 as l3_db
 from neutron.db.models import l3_attrs as l3_attrs_db
 from neutron.db import models_v2
-from neutron.extensions import l3 as l3_ext
 from neutron.plugins.ml2 import models as ml2_models
 
 from neutron_lib.api import validators
 from neutron_lib import constants as lib_consts
 from neutron_lib.db import model_base
 from neutron_lib import exceptions as n_exc
+from neutron_lib.exceptions import l3 as l3_exc
 from oslo_db import exception as oslo_db_exc
 from oslo_utils import uuidutils
 import sqlalchemy as sa
@@ -93,7 +93,7 @@ class BgpSpeaker(model_base.BASEV2,
     __tablename__ = 'bgp_speakers'
 
     name = sa.Column(sa.String(255), nullable=False)
-    local_as = sa.Column(sa.Integer, nullable=False, autoincrement=False)
+    local_as = sa.Column(sa.BigInteger(), nullable=False, autoincrement=False)
     advertise_floating_ip_host_routes = sa.Column(sa.Boolean, nullable=False)
     advertise_tenant_networks = sa.Column(sa.Boolean, nullable=False)
     peers = orm.relationship(BgpSpeakerPeerBinding,
@@ -118,7 +118,7 @@ class BgpPeer(model_base.BASEV2,
     name = sa.Column(sa.String(255), nullable=False)
     peer_ip = sa.Column(sa.String(64),
                         nullable=False)
-    remote_as = sa.Column(sa.Integer, nullable=False, autoincrement=False)
+    remote_as = sa.Column(sa.BigInteger(), nullable=False, autoincrement=False)
     auth_type = sa.Column(sa.String(16), nullable=False)
     password = sa.Column(sa.String(255), nullable=True)
 
@@ -148,7 +148,7 @@ class BgpDbMixin(common_db.CommonDbMixin):
     def get_bgp_speaker_with_advertised_routes(self, context,
                                                bgp_speaker_id):
         bgp_speaker_attrs = ['id', 'local_as', 'tenant_id']
-        bgp_peer_attrs = ['peer_ip', 'remote_as', 'auth_type', 'password']
+        bgp_peer_attrs = ['peer_ip', 'remote_as', 'password']
         with db_api.context_manager.reader.using(context):
             bgp_speaker = self.get_bgp_speaker(context, bgp_speaker_id,
                                                fields=bgp_speaker_attrs)
@@ -1025,7 +1025,7 @@ class BgpDbMixin(common_db.CommonDbMixin):
         try:
             router = self._get_by_id(context, l3_db.Router, router_id)
         except sa_exc.NoResultFound:
-            raise l3_ext.RouterNotFound(router_id=router_id)
+            raise l3_exc.RouterNotFound(router_id=router_id)
         return router
 
     def _get_fip_next_hop(self, context, router_id, ip_address=None):
