@@ -16,12 +16,12 @@
 import abc
 
 from neutron.api import extensions
-from neutron.api.v2 import base
 from neutron.api.v2 import resource
-from neutron.extensions import agent
 from neutron import wsgi
 from neutron_lib.api import extensions as api_extensions
+from neutron_lib.api import faults
 from neutron_lib import exceptions as n_exc
+from neutron_lib.exceptions import agent as agent_exc
 from neutron_lib.plugins import directory
 from oslo_log import log as logging
 import six
@@ -40,7 +40,7 @@ BGP_DRAGENT = 'bgp-dragent'
 BGP_DRAGENTS = BGP_DRAGENT + 's'
 
 
-class DrAgentInvalid(agent.AgentNotFound):
+class DrAgentInvalid(agent_exc.AgentNotFound):
     message = _("BgpDrAgent %(id)s is invalid or has been disabled.")
 
 
@@ -54,6 +54,11 @@ class DrAgentAssociationError(n_exc.Conflict):
                 "to a BGP speaker.")
 
 
+class BgpSpeakerRescheduleError(n_exc.Invalid):
+    message = _("Failed rescheduling %(bgp_speaker_id)s: "
+                "%(failure_reason)s.")
+
+
 class BgpDrSchedulerController(wsgi.Controller):
     """Schedule BgpSpeaker for a BgpDrAgent"""
     def get_plugin(self):
@@ -124,14 +129,14 @@ class Bgp_dragentscheduler(api_extensions.ExtensionDescriptor):
                       collection_name="agents")
 
         controller = resource.Resource(BgpDrSchedulerController(),
-                                       base.FAULT_MAP)
+                                       faults.FAULT_MAP)
         exts.append(extensions.ResourceExtension(BGP_DRINSTANCES,
                                                  controller, parent))
 
         parent = dict(member_name="bgp_speaker",
                       collection_name="bgp-speakers")
         controller = resource.Resource(BgpDrAgentController(),
-                                       base.FAULT_MAP)
+                                       faults.FAULT_MAP)
         exts.append(extensions.ResourceExtension(BGP_DRAGENTS,
                                                  controller, parent))
         return exts
